@@ -3,7 +3,7 @@ __author__ = 'Thierry Schellenbach'
 __copyright__ = 'Copyright 2012, Thierry Schellenbach'
 __credits__ = ['Thierry Schellenbach, mellowmorning.com, @tschellenbach']
 __license__ = 'BSD'
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 __maintainer__ = 'Thierry Schellenbach'
 __email__ = 'thierryschellenbach@gmail.com'
 __status__ = 'Production'
@@ -22,11 +22,7 @@ def connect(api_key, api_secret):
 
 '''
 TODO:
-
-pk_gt and pk_gte seems to have the same output (pk_gt doesnt always work)
-
-Test coverage
-Pypi entry
-Read the docs
-Travis setup
+- test coverage
+- read the docs
+- Update getstream.io/docs page
 '''
