@@ -1,6 +1,8 @@
 from unittest2.case import TestCase
 import stream
 import time
+from stream.exceptions import ApiKeyException, InputException,\
+    CustomFieldException
 
 
 class ClientTest(TestCase):
@@ -33,7 +35,7 @@ class ClientTest(TestCase):
         activity_data = {'actor': 1, 'verb': 'tweet', 'object': 1}
         activity_id = self.user1.add_activity(activity_data)['id']
         self.aggregated2.follow('user:1')
-        time.sleep(5)
+        time.sleep(10)
         activities = self.aggregated2.get(limit=3)['results']
         activity = self._get_first_aggregated_activity(activities)
         activity_id_found = activity['id'] if activity is not None else None
@@ -87,6 +89,36 @@ class ClientTest(TestCase):
         # try offset based
         activities = self.user1.get(limit=2, offset=1)['results']
         self.assertEqual(activities[0]['id'], activity_id_two)
-        # try pk_lt based
-        self.user1.get(limit=2, pk_lt=activity_id_two)['results']
+        # try id_lt based
+        activities = self.user1.get(limit=2, id_lt=activity_id_two)['results']
         self.assertEqual(activities[0]['id'], activity_id)
+
+    def test_api_key_exception(self):
+        self.c = stream.connect(
+            '5crf3bhfzesnMISSING',
+            'tfq2sdqpj9g446sbv653x3aqmgn33hsn8uzdc9jpskaw8mj6vsnhzswuwptuj9su'
+        )
+        self.user1 = self.c.feed('user:1')
+        activity_data = {'actor': 1, 'verb': 'tweet',
+                         'object': 1, 'debug_example_undefined': 'test'}
+        self.assertRaises(ApiKeyException, lambda:
+                          self.user1.add_activity(activity_data))
+
+    def test_missing_field_exception(self):
+        activity_data = {'actor': 1, 'verb': 'tweet',
+                         'object': 1, 'debug_example_undefined': 'test'}
+        self.assertRaises(CustomFieldException, lambda:
+                          self.user1.add_activity(activity_data))
+
+    def test_missing_actor(self):
+        activity_data = {'verb': 'tweet', 'object':
+                         1, 'debug_example_undefined': 'test'}
+        self.assertRaises(InputException, lambda:
+                          self.user1.add_activity(activity_data))
+
+    def test_wrong_feed_spec(self):
+        self.c = stream.connect(
+            '5crf3bhfzesnMISSING',
+            'tfq2sdqpj9g446sbv653x3aqmgn33hsn8uzdc9jpskaw8mj6vsnhzswuwptuj9su'
+        )
+        self.assertRaises(ValueError, lambda: self.c.feed('user1'))
